==> plone-2.5.3p2.tgz: lib/zope/lib/python/Products/Archetypes/atapi.py <==
# -*- coding: UTF-8 -*-
################################################################################
#
# Copyright (c) 2002-2005, Benjamin Saller <bcsaller@ideasuite.com>, and
#                              the respective authors. All rights reserved.
# For a list of Archetypes contributors see docs/CREDITS.txt.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# * Redistributions of source code must retain the above copyright notice, this
#   list of conditions and the following disclaimer.
# * Redistributions in binary form must reproduce the above copyright notice,
#   this list of conditions and the following disclaimer in the documentation
#   and/or other materials provided with the distribution.
# * Neither the name of the author nor the names of its contributors may be used
#   to endorse or promote products derived from this software without specific
#   prior written permission.
#
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
################################################################################

# registering and type processing
from Products.Archetypes.ArchetypeTool import registerType
from Products.Archetypes.ArchetypeTool import process_types
from Products.Archetypes.ArchetypeTool import listTypes
from Products.Archetypes.ArchetypeTool import registerClasses
# base classes
from Products.Archetypes.BaseObject import BaseObject
from Products.Archetypes.BaseContent import BaseContent
from Products.Archetypes.BaseContent import BaseContentMixin
from Products.Archetypes.BaseFolder import BaseFolder
from Products.Archetypes.BaseFolder import BaseFolderMixin
from Products.Archetypes.BaseBTreeFolder import BaseBTreeFolder
from Products.Archetypes.OrderedBaseFolder import OrderedBaseFolder
from Products.Archetypes.ExtensibleMetadata import ExtensibleMetadata
# base class schemata instances
from Products.Archetypes.BaseObject import MinimalSchema
from Products.Archetypes.BaseContent import BaseSchema
from Products.Archetypes.BaseFolder import BaseFolderSchema
from Products.Archetypes.BaseBTreeFolder import BaseBTreeFolderSchema
from Products.Archetypes.OrderedBaseFolder import OrderedBaseFolderSchema
from Products.Archetypes.ExtensibleMetadata import ExtensibleMetadataSchema
# schemata classes
from Products.Archetypes.Schema import BasicSchema
from Products.Archetypes.Schema import Schema
from Products.Archetypes.Schema import MetadataSchema
from Products.Archetypes.Schema import ManagedSchema
from Products.Archetypes.TemplateMixin import TemplateMixinSchema
from Products.Archetypes.Schema.Composite import CompositeSchema
from Products.Archetypes.Schema.Facade import FacadeMetadataSchema
from Products.Archetypes.VariableSchemaSupport import VariableSchemaSupport
# marshaller
from Products.Archetypes.Marshall import PrimaryFieldMarshaller
from Products.Archetypes.Marshall import RFC822Marshaller
# fields
from Products.Archetypes.Field import *
# widgets
from Products.Archetypes.Widget import *
# storage
from Products.Archetypes.Storage import *
from Products.Archetypes.Storage.annotation import AnnotationStorage
from Products.Archetypes.Storage.annotation import MetadataAnnotationStorage 
from Products.Archetypes.AggregatedStorage import AggregatedStorage
from Products.Archetypes.SQLStorage import BaseSQLStorage
from Products.Archetypes.SQLStorage import GadflySQLStorage
from Products.Archetypes.SQLStorage import MySQLSQLStorage
from Products.Archetypes.SQLStorage import PostgreSQLStorage
from Products.Archetypes.SQLStorage import SQLServerStorage
# annotation
from Products.Archetypes.annotations import getAnnotation
from Products.Archetypes.annotations import AT_ANN_STORAGE
from Products.Archetypes.annotations import AT_MD_STORAGE
from Products.Archetypes.annotations import AT_FIELD_MD
from Products.Archetypes.annotations import AT_REF
# misc
from Products.Archetypes.utils import DisplayList
from Products.Archetypes.utils import IntDisplayList
from Products.Archetypes.utils import Vocabulary
from Products.Archetypes.ClassGen import AT_GENERATE_METHOD
from Products.Archetypes.BaseUnit import BaseUnit
from Products.Archetypes.TemplateMixin import TemplateMixin
from Products.Archetypes.debug import log
from Products.Archetypes.debug import log_exc
from Products.Archetypes.BaseObject import AttributeValidator
from Products.Archetypes.athistoryaware import ATHistoryAwareMixin

# dynamicly calculate which modules should be exported
import sys
skipExports = ('skipExports', 'sys',)
__all__ = tuple([ export
                  for export in dir(sys.modules[__name__])
                  if export not in skipExports and not export.startswith('_')
                ])

==> plone-3.0.6p2.tgz: lib/zope/lib/python/Products/Archetypes/atapi.py <==
################################################################################
#
# Copyright (c) 2002-2005, Benjamin Saller <bcsaller@ideasuite.com>, and
#                              the respective authors. All rights reserved.
# For a list of Archetypes contributors see docs/CREDITS.txt.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# * Redistributions of source code must retain the above copyright notice, this
#   list of conditions and the following disclaimer.
# * Redistributions in binary form must reproduce the above copyright notice,
#   this list of conditions and the following disclaimer in the documentation
#   and/or other materials provided with the distribution.
# * Neither the name of the author nor the names of its contributors may be used
#   to endorse or promote products derived from this software without specific
#   prior written permission.
#
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
################################################################################

# registering and type processing
from Products.Archetypes.ArchetypeTool import registerType
from Products.Archetypes.ArchetypeTool import process_types
from Products.Archetypes.ArchetypeTool import listTypes
from Products.Archetypes.ArchetypeTool import registerClasses
# base classes
from Products.Archetypes.BaseObject import BaseObject
from Products.Archetypes.BaseContent import BaseContent
from Products.Archetypes.BaseContent import BaseContentMixin
from Products.Archetypes.BaseFolder import BaseFolder
from Products.Archetypes.BaseFolder import BaseFolderMixin
from Products.Archetypes.BaseBTreeFolder import BaseBTreeFolder
from Products.Archetypes.OrderedBaseFolder import OrderedBaseFolder
from Products.Archetypes.ExtensibleMetadata import ExtensibleMetadata
# base class schemata instances
from Products.Archetypes.BaseObject import MinimalSchema
from Products.Archetypes.BaseContent import BaseSchema
from Products.Archetypes.BaseFolder import BaseFolderSchema
from Products.Archetypes.BaseBTreeFolder import BaseBTreeFolderSchema
from Products.Archetypes.OrderedBaseFolder import OrderedBaseFolderSchema
from Products.Archetypes.ExtensibleMetadata import ExtensibleMetadataSchema
# schemata classes
from Products.Archetypes.Schema import BasicSchema
from Products.Archetypes.Schema import Schema
from Products.Archetypes.Schema import MetadataSchema
from Products.Archetypes.Schema import ManagedSchema
from Products.Archetypes.TemplateMixin import TemplateMixinSchema
from Products.Archetypes.Schema.Composite import CompositeSchema
from Products.Archetypes.Schema.Facade import FacadeMetadataSchema
from Products.Archetypes.VariableSchemaSupport import VariableSchemaSupport
# marshaller
from Products.Archetypes.Marshall import PrimaryFieldMarshaller
from Products.Archetypes.Marshall import RFC822Marshaller
# fields
from Products.Archetypes.Field import *
# widgets
from Products.Archetypes.Widget import *
# storage
from Products.Archetypes.Storage import *
from Products.Archetypes.Storage.annotation import AnnotationStorage
from Products.Archetypes.Storage.annotation import MetadataAnnotationStorage 
from Products.Archetypes.AggregatedStorage import AggregatedStorage
from Products.Archetypes.SQLStorage import BaseSQLStorage
from Products.Archetypes.SQLStorage import GadflySQLStorage
from Products.Archetypes.SQLStorage import MySQLSQLStorage
from Products.Archetypes.SQLStorage import PostgreSQLStorage
from Products.Archetypes.SQLStorage import SQLServerStorage
# annotation
from Products.Archetypes.annotations import getAnnotation
from Products.Archetypes.annotations import AT_ANN_STORAGE
from Products.Archetypes.annotations import AT_MD_STORAGE
from Products.Archetypes.annotations import AT_FIELD_MD
from Products.Archetypes.annotations import AT_REF
# misc
from Products.Archetypes.utils import DisplayList
from Products.Archetypes.utils import IntDisplayList
from Products.Archetypes.utils import Vocabulary
from Products.Archetypes.ClassGen import AT_GENERATE_METHOD
from Products.Archetypes.BaseUnit import BaseUnit
from Products.Archetypes.TemplateMixin import TemplateMixin
from Products.Archetypes.debug import log
from Products.Archetypes.debug import log_exc
from Products.Archetypes.BaseObject import AttributeValidator
from Products.Archetypes.athistoryaware import ATHistoryAwareMixin
from Products.Archetypes.fieldproperty import ATFieldProperty
from Products.Archetypes.fieldproperty import ATReferenceFieldProperty
from Products.Archetypes.fieldproperty import ATDateTimeFieldProperty

# dynamicly calculate which modules should be exported
import sys
skipExports = ('skipExports', 'sys',)
__all__ = tuple([ export
                  for export in dir(sys.modules[__name__])
                  if export not in skipExports and not export.startswith('_')
                ])
